@@ -10,9 +10,9 @@ config() {
   # Otherwise, we leave the .new copy for the admin to consider...
 }
 config etc/irssi.conf.new
-( cd usr/doc/irssi-0.8.10a/docs ; rm -rf help )
-( cd usr/doc/irssi-0.8.10a/docs ; ln -sf /usr/share/irssi/help help )
 ( cd usr/lib/irssi/modules ; rm -rf libirc_proxy.so )
 ( cd usr/lib/irssi/modules ; ln -sf libirc_proxy.so.0.0.0 libirc_proxy.so )
 ( cd usr/lib/irssi/modules ; rm -rf libirc_proxy.so.0 )
 ( cd usr/lib/irssi/modules ; ln -sf libirc_proxy.so.0.0.0 libirc_proxy.so.0 )
+( cd usr/doc/irssi-0.8.11/docs ; rm -rf help )
+( cd usr/doc/irssi-0.8.11/docs ; ln -sf /usr/share/irssi/help help )
